layouttools.set_line_breaks_cyclically_by_line_duration_in_seconds_ge
=====================================================================

.. autofunction:: abjad.tools.layouttools.set_line_breaks_cyclically_by_line_duration_in_seconds_ge.set_line_breaks_cyclically_by_line_duration_in_seconds_ge
